@@ -22,7 +22,7 @@ package MongoDB;
 # ABSTRACT: Official MongoDB Driver for Perl
 
 use version;
-our $VERSION = 'v1.0.0';
+our $VERSION = 'v1.0.1';
 
 # regexp_pattern was unavailable before 5.10, had to be exported to load the
 # function implementation on 5.10, and was automatically available in 5.10.1
@@ -65,6 +65,11 @@ if ( $] eq '5.010' ) {
 #pod
 #pod If an error occurs, a L<MongoDB::Error> object will be thrown.
 #pod
+#pod B<NOTE>: To connect to a replica set, a replica set name must be provided.
+#pod For example, if the set name is "setA":
+#pod
+#pod     $client = MongoDB->connect("mongodb://example.com/?replicaSet=setA");
+#pod
 #pod =cut
 
 sub connect {
@@ -101,7 +106,7 @@ MongoDB - Official MongoDB Driver for Perl
 
 =head1 VERSION
 
-version v1.0.0
+version v1.0.1
 
 =head1 SYNOPSIS
 
@@ -109,8 +114,8 @@ version v1.0.0
 
     my $client     = MongoDB->connect('mongodb://localhost');
     my $collection = $client->ns('foo.bar'); # database foo, collection bar
-    my $id         = $collection->insert_one({ some => 'data' });
-    my $data       = $collection->find_one({ _id => $id });
+    my $result     = $collection->insert_one({ some => 'data' });
+    my $data       = $collection->find_one({ _id => $result->inserted_id });
 
 =head1 DESCRIPTION
 
@@ -199,6 +204,11 @@ for L<MongoDB::MongoClient::new|MongoDB::MongoClient/ATTRIBUTES>.
 
 If an error occurs, a L<MongoDB::Error> object will be thrown.
 
+B<NOTE>: To connect to a replica set, a replica set name must be provided.
+For example, if the set name is "setA":
+
+    $client = MongoDB->connect("mongodb://example.com/?replicaSet=setA");
+
 =for Pod::Coverage force_double
 force_int
 read_documents
