@@ -20,7 +20,7 @@ package MongoDB::Collection;
 # ABSTRACT: A MongoDB Collection
 
 use version;
-our $VERSION = 'v1.0.0';
+our $VERSION = 'v1.0.1';
 
 use MongoDB::Error;
 use MongoDB::IndexView;
@@ -588,9 +588,10 @@ sub update_many {
 #pod the MongoDB documentation.
 #pod
 #pod B<Note>, a L<MongoDB::Cursor> object holds the query and does not issue the
-#pod query to the server until the C<request> method is called on it or until an
-#pod iterator method like C<next> is called.  Performance will be better directly on
-#pod a L<MongoDB::QueryResult> object:
+#pod query to the server until the L<result|MongoDB::Cursor/result> method is
+#pod called on it or until an iterator method like L<next|MongoDB::Cursor/next>
+#pod is called.  Performance will be better directly on a
+#pod L<MongoDB::QueryResult> object:
 #pod
 #pod     my $query_result = $coll->find( $filter )->result;
 #pod
@@ -1715,7 +1716,7 @@ MongoDB::Collection - A MongoDB Collection
 
 =head1 VERSION
 
-version v1.0.0
+version v1.0.1
 
 =head1 SYNOPSIS
 
@@ -2066,9 +2067,10 @@ Overview|http://docs.mongodb.org/manual/core/read-operations-introduction/> in
 the MongoDB documentation.
 
 B<Note>, a L<MongoDB::Cursor> object holds the query and does not issue the
-query to the server until the C<request> method is called on it or until an
-iterator method like C<next> is called.  Performance will be better directly on
-a L<MongoDB::QueryResult> object:
+query to the server until the L<result|MongoDB::Cursor/result> method is
+called on it or until an iterator method like L<next|MongoDB::Cursor/next>
+is called.  Performance will be better directly on a
+L<MongoDB::QueryResult> object:
 
     my $query_result = $coll->find( $filter )->result;
 
