@@ -19,7 +19,7 @@ package MongoDB::MongoClient;
 # ABSTRACT: A connection to a MongoDB server or multi-server deployment
 
 use version;
-our $VERSION = 'v1.0.0';
+our $VERSION = 'v1.0.1';
 
 use Moo;
 use MongoDB;
@@ -1508,7 +1508,7 @@ MongoDB::MongoClient - A connection to a MongoDB server or multi-server deployme
 
 =head1 VERSION
 
-version v1.0.0
+version v1.0.1
 
 =head1 SYNOPSIS
 
@@ -1528,6 +1528,11 @@ version v1.0.0
         replica_set_name => 'myset',
     );
 
+    # connect to a replica set with URI (set name *required*)
+    my $client = MongoDB::MongoClient->new(
+        host => "mongodb://mongo1.example.com,mongo2.example.com/?replicaSet=myset",
+    );
+
     my $db = $client->get_database("test");
     my $coll = $db->get_collection("people");
 
